#/bin/make
###############################################################################
#                       Make file for OCI and OCCI demos
###############################################################################
#  Usage :
# For compiling & linking the cdemo81.c file
#    make -f demo.mk buildoci EXE=cdemo81 OBJS=cdemo81.o 
#
# For compiling & linking the occidml.cpp
#    make -f demo.mk buildocci EXE=occidml OBJS=occidml.o
#
# For compiling & linking the occiobj.cpp
#    make -f demo.mk occiobj 
#
# In general, for any occi program
#    make -f demo.mk buildocci EXE=<exename> OBJS="<list of dependent objs>"
#
# For compiling all demos
#    make -f demo.mk
#
# NOTE: Please change cc and CC to point to the appropiate location on your
#       machine.
#
###############################################################################

.SUFFIXES: .o .c .cpp

CC=/opt/ibmcmp/vacpp/6.0/bin/xlC -q64
cc=/opt/ibmcmp/vac/6.0/bin/xlc -q64

ICINCHOME=../
ICLIBHOME=../../
ICLIBPATH=-L$(ICLIBHOME)
THREADLIBS=-lpthread
CCLIB=$(ICLIBPATH) -locci -lclntsh $(THREADLIBS)

CCINCLUDES = -I$(ICINCHOME)include

CCFLAGS=$(CCINCLUDES) -D_REENTRANT -g -xs 
LDFLAGS=
SO_EXT=.so

REMOVE=rm -rf
MKLINK=ln
MAKE=make
MAKEFILE=demo.mk
CLNCACHE=cleancache
CACHEDIR=SunWS_cache

CDEMOEXE=cdemo81
CDEMOOBJS=cdemo81.o
OCCIDEMO=occidml
OCCIOBJDEMO=occiobj
OTT=../ott
OCCIOTTUSR=hr
OCCIOTTPWD=hr

.cpp.o:
	$(CC) -c -I$(ICINCHOME)include $(CCFLAGS) $<

.c.o:
	$(cc) -c -I$(ICINCHOME)include $(CCFLAGS) $<

all: clean buildoci $(OCCIDEMO) $(OCCIOBJDEMO)

buildoci: $(CLNCACHE) $(LIBCLNT) $(CDEMOOBJS)
	$(MKLINK) $(ICLIBHOME)libclntsh$(SO_EXT).10.1 $(ICLIBHOME)libclntsh$(SO_EXT)
	$(MKLINK) $(ICLIBHOME)libocci$(SO_EXT).10.1 $(ICLIBHOME)libocci$(SO_EXT)
	$(CC) -o $(CDEMOEXE) $(LDFLAGS) $(CDEMOOBJS) $(CCLIB)
	$(REMOVE) $(ICLIBHOME)libclntsh$(SO_EXT)
	$(REMOVE) $(ICLIBHOME)libocci$(SO_EXT)

buildocci: $(CLNCACHE) $(LIBCLNT) $(OBJS)
	$(MKLINK) $(ICLIBHOME)libclntsh$(SO_EXT).10.1 $(ICLIBHOME)libclntsh$(SO_EXT)
	$(MKLINK) $(ICLIBHOME)libocci$(SO_EXT).10.1 $(ICLIBHOME)libocci$(SO_EXT)
	$(CC) -o $(EXE) $(LDFLAGS) $(OBJS) $(CCLIB)
	$(REMOVE) $(ICLIBHOME)libclntsh$(SO_EXT)
	$(REMOVE) $(ICLIBHOME)libocci$(SO_EXT)

$(OCCIDEMO):
	$(MAKE) -f $(MAKEFILE) buildocci OBJS=$@.o EXE=$@

$(OCCIOBJDEMO):
	$(OTT) userid=$(OCCIOTTUSR)/$(OCCIOTTPWD) \
                intype=$@.typ \
                outtype=$@out.type \
                code=cpp \
                hfile=$@.h \
                cppfile=$@o.cpp \
                attraccess=private \
                unicode=none
	$(MAKE) -f $(MAKEFILE) buildocci OBJS="$@.o $@m.o $@o.o" EXE=$@

cleancache:
	$(REMOVE) $(CACHEDIR)
	$(REMOVE) $(ICLIBHOME)libclntsh$(SO_EXT)
	$(REMOVE) $(ICLIBHOME)libocci$(SO_EXT)

clean: $(CLNCACHE)
	$(REMOVE) cdemo81 cdemo81.o occidml occidml.o occiobj occiobj.o occiobjo* occiobjm* occiobj.h occiobjout.type

#
# This port-specific file is currently empty on Solaris. Product
# lines may use this file to override compiler definitions and
# flags used in occi.mk.
#

# Linux PowerPPC compiler definitions

OCCILIBPATH32=-L$(SRCHOME)/rdbms/lib32/ -L$(SRCHOME)/lib32/ $(ICLIBPATH)
OCCILIBPATH64=-L$(SRCHOME)/rdbms/lib/ -L$(SRCHOME)/lib/ $(ICLIBPATH)

DISTRO=$(shell if test -f /etc/redhat-release ; then echo "RH4"; else echo "NotRH4"; fi)

LoPLINK=g++

ifeq ($(COMPILER), VAC)
  LoPCC=/opt/ibmcmp/vacpp/7.0/bin/xlC
  LoPcc=/opt/ibmcmp/vacpp/7.0/bin/xlc
  BIT_MODE32=-q32
  BIT_MODE64=-q64
else
  ifeq ($(DISTRO), RH4)
    LoPCC=g++32
    LoPLINK=g++32
  else
    LoPCC=g++
  endif
  LoPcc=gcc
  BIT_MODE32=-m32
  BIT_MODE64=-m64
endif

VACLIBS32=-L/opt/ibmcmp/vac/7.0/lib -lxl -Wl,-rpath /opt/ibmcmp/lib /opt/ibmcmp/lib/libibmc++.so.1
VACLIBS64=-L/opt/ibmcmp/vac/7.0/lib64 -lxl -Wl,-rpath /opt/ibmcmp/lib64 /opt/ibmcmp/lib64/libibmc++.so.1

CCLIB32=$(OCCILIBPATH32) -locci -lclntsh $(VACLIBS32) $(THREADLIBS)
CCLIB64=$(OCCILIBPATH64) -locci -lclntsh $(VACLIBS64) $(THREADLIBS)

ifeq ($(COMPILER_MODE), 32)
  CC=$(LoPCC) $(BIT_MODE32)
  cc=$(LoPcc) $(BIT_MODE32)
  CCFLAGS += -DBUILD32
  CCLIB=$(CCLIB32)
  VACLIBS=$(VACLIBS32)
  LINK=$(LoPLINK) -m32
else
  CC=$(LoPCC) $(BIT_MODE64)
  cc=$(LoPcc) $(BIT_MODE64)
  CCLIB=$(CCLIB64)
  VACLIBS=$(VACLIBS64)
  LINK=$(LoPLINK) -m64
endif

CCFLAGS=$(CCINCLUDES) -DLINUX -DLINUX_PPC64 -D_GNU_SOURCE -D_REENTRANT -g 
LDFLAGS=-g
CLNCACHE=
THREADLIBS=-lpthread


build: $(CLNCACHE) $(OBJS) $(OTHEROBJS) $(MOBJS)
	$(LINK) -o $(EXE) $(LDFLAGS) $(OTHEROBJS) $(MOBJS) $(OBJS) $(CCLIB)

